Package: EBSeq
Type: Package
Title: An R package for gene and isoform differential expression
        analysis of RNA-seq data
Version: 2.8.0
Date: 2015-12-8
Authors@R: c(person("Xiuyu", "Ma", email = "watsonforfun@gmail.com", role = c("cre", "aut")), 
	person("Ning", "Leng", email = "lengning1@gmail.com", role = c("aut")),
	person("Christina", "Kendziorski", email = "kendzior@biostat.wisc.edu", role = c("ctb")),
	person("Michael A.", "Newton", email = "newton@stat.wisc.edu", role = c("ctb")))
Depends: blockmodeling, gplots, testthat, R (>= 3.0.0)
Description: Differential Expression analysis at both gene and isoform
        level using RNA-seq data
License: Artistic-2.0
LazyLoad: yes
Collate: 'MedianNorm.R' 'GetNg.R' 'beta.mom.R' 'EBTest.R'
        'GetPatterns.R' 'EBMultiTest.R' 'PostFC.R' 'GetPPMat.R'
        'GetMultiPP.R' 'GetMultiFC.R' 'PlotPostVsRawFC.R' 'crit_fun.R'
        'DenNHist.R' 'GetNormalizedMat.R' 'PlotPattern.R'
        'PolyFitPlot.R' 'QQP.R' 'QuantileNorm.R' 'RankNorm.R'
        'GetDEResults.R' 'EBSeqTest.R' 'Likefun.R' 'LikefunMulti.R'
        'LogN.R' 'LogNMulti.R' 'f0.R' 'f1.R' 'GetSelectedPatterns.R'
BuildVignettes: no
Imports: Rcpp (>= 0.12.11), RcppEigen (>= 0.3.2.9.0), BH (<= 1.87.0-1)
LinkingTo: Rcpp,RcppEigen,BH
SystemRequirements: c++14
Roxygen: list(wrap=FALSE)
RoxygenNote: 7.1.0
biocViews: ImmunoOncology, StatisticalMethod, DifferentialExpression,
        MultipleComparison, RNASeq, Sequencing
NeedsCompilation: yes
Packaged: 2025-10-30 03:44:58 UTC; biocbuild
git_url: https://git.bioconductor.org/packages/EBSeq
git_branch: RELEASE_3_22
git_last_commit: f20617a
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
Author: Xiuyu Ma [cre, aut],
  Ning Leng [aut],
  Christina Kendziorski [ctb],
  Michael A. Newton [ctb]
Maintainer: Xiuyu Ma <watsonforfun@gmail.com>
