export(crit_fun, DenNHist, EBTest, GetNg, GetPP, MedianNorm, 
PolyFitPlot, PostFC, QQP, QuantileNorm, RankNorm, EBMultiTest, 
GetMultiPP, GetPatterns, PlotPattern, GetPPMat, GetMultiFC, PlotPostVsRawFC,
GetNormalizedMat)

