\name{GeneMat}
\alias{GeneMat}
\docType{data}
\title{
The simulated data for two condition gene DE analysis
}
\description{
'GeneMat' gives the simulated data for two condition gene DE analysis.
}
\usage{data(GeneMat)}
\source{
Ning Leng, John A. Dawson, James A. Thomson, Victor Ruotti, Anna I. Rissman, Bart M.G. Smits, Jill D. Haag, Michael N. Gould, Ron M. Stewart, and Christina Kendziorski. EBSeq: An empirical Bayes hierarchical model for inference in RNA-seq experiments.  Bioinformatics (2013)
}
\seealso{
IsoList
}
\examples{
data(GeneMat)
}
\keyword{datasets}
