\name{IsoMultiList}
\alias{IsoMultiList}
\docType{data}
\title{
The simulated data for multiple condition isoform DE analysis
}
\description{
'IsoMultiList' gives a set of simulated data for multiple condition isoform DE analysis.
}
\usage{data(IsoMultiList)}
\source{
Ning Leng, John A. Dawson, James A. Thomson, Victor Ruotti, Anna I. Rissman, Bart M.G. Smits, Jill D. Haag, Michael N. Gould, Ron M. Stewart, and Christina Kendziorski. EBSeq: An empirical Bayes hierarchical model for inference in RNA-seq experiments. Bioinformatics (2013)
}
\seealso{IsoList
}
\examples{
data(IsoMultiList)
}
\keyword{datasets}
