\name{PlotPattern}
\alias{PlotPattern}
\title{
Visualize the patterns
}
\description{
'PlotPattern' generates the visualized patterns before the multiple condition test.
}
\usage{
PlotPattern(Patterns)
}
\arguments{
  \item{Patterns}{
The output of GetPatterns function.
}

}
\value{
A heatmap to visualize the patterns of interest.
}

\references{
Ning Leng, John A. Dawson, James A. Thomson, Victor Ruotti, Anna I. Rissman, Bart M.G. Smits, Jill D. Haag, Michael N. Gould, Ron M. Stewart, and Christina Kendziorski. EBSeq: An empirical Bayes hierarchical model for inference in RNA-seq experiments. Bioinformatics (2013)
}

\author{
Ning Leng
}

\examples{
Conditions = c("C1","C1","C2","C2","C3","C3")
Patterns = GetPatterns(Conditions)
PlotPattern(Patterns)

}
\keyword{ patterns }
