\name{IsoList}
\alias{IsoList}
\docType{data}
\title{
The simulated data for two condition isoform DE analysis
}
\description{
'IsoList' gives the simulated data for two condition isoform DE analysis.
}
\usage{data(IsoList)}
\source{
Ning Leng, John A. Dawson, James A. Thomson, Victor Ruotti, Anna I. Rissman, Bart M.G. Smits, Jill D. Haag, Michael N. Gould, Ron M. Stewart, and Christina Kendziorski. EBSeq: An empirical Bayes hierarchical model for inference in RNA-seq experiments. Bioinformatics (2013)
}
\seealso{GeteMat}

\examples{
data(IsoList)
}
\keyword{datasets}
